-- ============================================================================
-- 酒店集团子品牌数据表 DDL
-- 基于文件: 人才地图-字典20250519.xlsx - 各集团子品牌 sheet
-- 创建时间: 2025-01-19
-- 数据规模: 295条记录，27个集团，290个品牌，6个定位级别
-- ============================================================================

CREATE TABLE hotel_group_brands (
    -- 主键ID，自增序列
    id SERIAL PRIMARY KEY,
  
    -- 集团信息
    group_name_en VARCHAR(60) NOT NULL,
    
    group_name_zh VARCHAR(20) NOT NULL,
    
    -- 品牌信息
    brand_name_en VARCHAR(40) NOT NULL,
    
    brand_name_zh VARCHAR(40) NOT NULL,
    
    -- 定位级别信息
    positioning_level_en VARCHAR(20) NOT NULL,
    
    positioning_level_zh VARCHAR(5) NOT NULL,
    
    -- 审计字段
    created_at TIMESTAMP WITH TIME ZONE DEFAULT CURRENT_TIMESTAMP,
    
    updated_at TIMESTAMP WITH TIME ZONE DEFAULT CURRENT_TIMESTAMP,
    
    created_by VARCHAR(50) DEFAULT 'system',
    
    updated_by VARCHAR(50) DEFAULT 'system',
    
    status VARCHAR(20) DEFAULT 'active'
);

-- ============================================================================
-- 表注释
-- ============================================================================

COMMENT ON TABLE hotel_group_brands IS '酒店集团子品牌数据表
用途：存储全球酒店集团及其子品牌的标准化信息
数据来源：人才地图-字典20250519.xlsx
包含内容：27个酒店集团，290个品牌，6个定位级别
维护说明：定期更新以保持与行业标准一致';

-- ============================================================================
-- 字段注释
-- ============================================================================

COMMENT ON COLUMN hotel_group_brands.id IS '主键ID，系统自动生成';
COMMENT ON COLUMN hotel_group_brands.sequence_no IS '序号，对应Excel中的原始序号，共34个不同序号';
COMMENT ON COLUMN hotel_group_brands.group_name_en IS '集团英文名称，最大长度50个字符，如：IHG Hotels & Resorts，共27个不同集团';
COMMENT ON COLUMN hotel_group_brands.group_name_zh IS '集团中文名称，最大长度12个字符，如：洲际酒店集团，共27个不同集团';
COMMENT ON COLUMN hotel_group_brands.brand_name_en IS '品牌英文名称，最大长度35个字符，如：InterContinental，共290个不同品牌';
COMMENT ON COLUMN hotel_group_brands.brand_name_zh IS '品牌中文名称，最大长度31个字符，如：洲际酒店及度假村，共294个不同品牌';
COMMENT ON COLUMN hotel_group_brands.positioning_level_en IS '定位级别英文名称，最大长度14个字符，如：Upper Upscale，共6个级别';
COMMENT ON COLUMN hotel_group_brands.positioning_level_zh IS '定位级别中文名称，最大长度3个字符，如：超高端，共6个级别';
COMMENT ON COLUMN hotel_group_brands.created_at IS '记录创建时间，带时区';
COMMENT ON COLUMN hotel_group_brands.updated_at IS '记录最后更新时间，带时区';
COMMENT ON COLUMN hotel_group_brands.created_by IS '记录创建者用户标识';
COMMENT ON COLUMN hotel_group_brands.updated_by IS '记录最后更新者用户标识';
COMMENT ON COLUMN hotel_group_brands.status IS '记录状态，active=有效，inactive=无效'; 